#include "wii.h"

/*
 * Copyright (C) 2000-2006 Erik Andersen <andersen@uclibc.org>
 *
 * Licensed under the LGPL v2.1, see the file COPYING.LIB in this tarball.
 */


#include <dirent.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <errno.h>
#include <sys/types.h>


int alphasort(const struct dirent **d1, const struct dirent **d2)
{
	    const struct dirent *c1;
	    const struct dirent *c2;
	    c1 = *d1;
	    c2 = *d2;
	    return strcmp(c1->d_name, c2->d_name);
}

int scandir(const char *dirp, struct dirent ***namelist,
              int (*filter)(const struct dirent *),
              int (*compar)(const struct dirent **, const struct dirent **))

{

    DIR *dp = opendir (dirp);
    struct dirent *current;
    struct dirent **names = NULL;
    size_t names_size = 0, pos;
    int save;

    if (dp == NULL)
        return -1;

    save = errno;

    errno = 0;

    pos = 0;
    while ((current = readdir (dp)) != NULL)
        if (filter == NULL || (*filter) (current))
        {
            struct dirent *vnew;
            size_t dsize;

            if (pos == names_size)
            {
                struct dirent **new;
                if (names_size == 0)
                    names_size = 10;
                else
                    names_size *= 2;
                new = (struct dirent **) realloc (names, names_size * sizeof (struct dirent *));
                if (new == NULL)
                    break;
                names = new;
            }

            dsize = &current->d_name[strlen(current->d_name)+1] - (char *) current;
            vnew = (struct dirent *) malloc (dsize);
            if (vnew == NULL)
                break;

            names[pos++] = (struct dirent *) memcpy (vnew, current, dsize);
        }

    if (errno != 0)
    {
        save = errno;
        closedir (dp);
        while (pos > 0)
            free (names[--pos]);
        free (names);

        return -1;
    }

    closedir (dp);


    /* Sort the list if we have a comparison function to sort with.  */
    if (compar != NULL)
        qsort (names, pos, sizeof (struct dirent *), compar);
    *namelist = names;
    return pos;
}


int chmod(const char *path, mode_t mode)
{
	return 0;
}

int rmdir(const char *pathname)
{
	return EPERM;
}
